@@ -15,9 +15,9 @@
 //           }
 //       }).run();
 //
-var util = require('util'),
-    path = require('path'),
+var path = require('path'),
     events = require('events'),
+    util = require('util'),
     vows = exports;
 
 // Options
@@ -65,6 +65,9 @@ function addVow(vow) {
 
     // always set a listener on the event
     this.on(event, function () {
+        if(vow.caughtError)
+            return;
+
         var args = Array.prototype.slice.call(arguments);
         // If the vow is a sub-event then we know it is an
         // emitted event.  So I don't muck with the arguments
@@ -81,10 +84,11 @@ function addVow(vow) {
 
     if (event !== 'error') {
         this.on("error", function (err) {
+            vow.caughtError = true;
             if (vow.callback.length >= 2 || !batch.suite.options.error) {
                 runTest(arguments, this.ctx);
             } else {
-                output('errored', { type: 'promise', error: err.stack ||
+                output('errored', { type: 'emitter', error: err.stack ||
                        err.message || JSON.stringify(err) });
             }
             vows.tryEnd(batch);
@@ -119,7 +123,7 @@ function addVow(vow) {
             var after = vow.binding.context.after;
             // only need to check order.  I won't get here if the after event
             // has never been emitted
-            if (self._vowsEmitedEventsOrder.indexOf(after) > 
+            if (self._vowsEmitedEventsOrder.indexOf(after) >
                 self._vowsEmitedEventsOrder.indexOf(event)) {
                 output('broken', event + ' emitted before ' + after);
                 return;
@@ -133,7 +137,7 @@ function addVow(vow) {
             output('honored');
         } catch (e) {
             if (e.name && e.name.match(/AssertionError/)) {
-                output('broken', e.toString().replace(/\`/g, '`'));
+                output('broken', e.toStringEx().replace(/\`/g, '`'));
             } else {
                 output('errored', e.stack || e.message || e);
             }
@@ -158,7 +162,7 @@ function addVow(vow) {
 };
 
 //
-// On exit, check that all promises have been fired.
+// On exit, check that all emitters have been fired.
 // If not, report an error message.
 //
 process.on('exit', function () {
@@ -181,7 +185,7 @@ process.on('exit', function () {
                 }
             });
 
-            if (unFired.length > 0) { util.print('\n') }
+            if (unFired.length > 0) { util.print('\n'); }
 
             unFired.forEach(function (title) {
                 s.reporter.report(['error', {
