@@ -11,22 +11,22 @@ var api = vows.prepare({
     version: function () { return '1.0' }
 }, ['get']);
 
-var promiser = function (val) {
+var emitNextTick = function (val) {
     return function () {
-        var promise = new(events.EventEmitter);
-        process.nextTick(function () { promise.emit('success', val) });
-        return promise;
+        var emitter = new(events.EventEmitter);
+        process.nextTick(function () { emitter.emit('success', val) });
+        return emitter;
     }
 };
 
 vows.describe("Vows").addBatch({
     "A context": {
-        topic: promiser("hello world"),
+        topic: emitNextTick("hello world"),
 
         "with a nested context": {
             topic: function (parent) {
                 this.state = 42;
-                return promiser(parent)();
+                return emitNextTick(parent)();
             },
             "has access to the environment": function () {
                 assert.equal(this.state, 42);
@@ -47,16 +47,16 @@ vows.describe("Vows").addBatch({
         }
     },
     "A nested context": {
-        topic: promiser(1),
+        topic: emitNextTick(1),
 
         ".": {
-            topic: function (a) { return promiser(2)() },
+            topic: function (a) { return emitNextTick(2)() },
 
             ".": {
-                topic: function (b, a) { return promiser(3)() },
+                topic: function (b, a) { return emitNextTick(3)() },
 
                 ".": {
-                    topic: function (c, b, a) { return promiser([4, c, b, a])() },
+                    topic: function (c, b, a) { return emitNextTick([4, c, b, a])() },
 
                     "should have access to the parent topics": function (topics) {
                         assert.equal(topics.join(), [4, 3, 2, 1].join());
@@ -64,7 +64,7 @@ vows.describe("Vows").addBatch({
                 },
 
                 "from": {
-                    topic: function (c, b, a) { return promiser([4, c, b, a])() },
+                    topic: function (c, b, a) { return emitNextTick([4, c, b, a])() },
 
                     "the parent topics": function(topics) {
                         assert.equal(topics.join(), [4, 3, 2, 1].join());
@@ -121,9 +121,9 @@ vows.describe("Vows").addBatch({
             }
         }
     },
-    "A non-promise return value": {
+    "A non-EventEmitter return value": {
         topic: function () { return 1 },
-        "should be converted to a promise": function (val) {
+        "should be converted to a vow": function (val) {
             assert.equal(val, 1);
         }
     },
@@ -168,24 +168,16 @@ vows.describe("Vows").addBatch({
             "should work as expected": function (topic) {
                 assert.isFunction(topic);
                 assert.equal(topic(), 42);
-            },
-        }
-    },
-    "A topic with a function that errors": {
-        topic: function() {
-            throw("Something wrong here");
-        },
-        "should error out": function(topic) {
-            assert.equal(topic, "Something wrong here");
+            }
         }
     },
     "A topic emitting an error": {
         topic: function () {
-            var promise = new(events.EventEmitter);
+            var emitter = new(events.EventEmitter);
             process.nextTick(function () {
-                promise.emit("error", 404);
+                emitter.emit("error", 404);
             });
-            return promise;
+            return emitter;
         },
         "shouldn't raise an exception if the test expects it": function (e, res) {
             assert.equal(e, 404);
@@ -194,11 +186,11 @@ vows.describe("Vows").addBatch({
     },
     "A topic not emitting an error": {
         topic: function () {
-            var promise = new(events.EventEmitter);
+            var emitter = new(events.EventEmitter);
             process.nextTick(function () {
-                promise.emit("success", true);
+                emitter.emit("success", true);
             });
-            return promise;
+            return emitter;
         },
         "should pass `null` as first argument, if the test is expecting an error": function (e, res) {
             assert.strictEqual(e, null);
@@ -299,13 +291,157 @@ vows.describe("Vows").addBatch({
                 assert.equal(res.foo, true);
             }
         },
-        "'B', with nothing set": {
+        "'B', with `this.bar = true`": {
+            topic: function () {
+                this.bar = true;
+                return 42;
+            },
+            "should pass the result": function (res) {
+                assert.equal(res, 42);
+            },
+            "should have `this.bar` set to true": function () {
+                assert.equal(this.bar, true);
+            },
+            'with a sub context': {
+              topic: function(){
+                this.barSubContext = { sub: true }
+                return 42;
+              },
+              "should have `this.bar` set to true": function (res) {
+                  assert.equal(this.bar, true);
+              },
+              "should have `this.barSubContext`": function (res) {
+                  assert.deepEqual(this.barSubContext, { sub: true });
+              },
+              'with gaps': {
+                '.': {
+                  '.': {
+                    '.': {
+                      topic: 12,
+                      '.': {
+                        '.': {
+                          topic: function(){
+                            this.barSubContext.subsub = true;
+                            return 42;
+                          },
+                          "should have `this.bar` set to true": function (res) {
+                              assert.equal(this.bar, true);
+                          },
+                          'should have `this.barSubContext`': function(){
+                            assert.deepEqual(this.barSubContext, { sub: true, subsub: true });
+                          }
+                        }
+                      }
+                    }
+                  }
+                }
+              }
+            }
+        },
+        "'C', with nothing set": {
             topic: function () {
                 return this;
             },
+            "shouldn't have access to `this.foo`": function (res) {
+                assert.isUndefined(res.foo);
+                assert.isUndefined(this.foo);
+            },
+            "shouldn't have access to `this.bar`": function (res) {
+                assert.isUndefined(res.bar);
+                assert.isUndefined(this.bar);
+            },
+            "shouldn't have access to `this.barSubContext`": function (res) {
+                assert.isUndefined(res.barSubContext);
+                assert.isUndefined(this.barSubContext);
+            }
+        }
+    },
+    "Sibling context asynchronous": {
+        "'A', with `this.foo = true`": {
+            topic: function () {
+                this.foo = true;
+                var self = this;
+                process.nextTick(function(){
+                  self.callback(null, self);
+                })
+            },
+            "should have `this.foo` set to true": function (res) {
+                assert.equal(res.foo, true);
+            }
+        },
+        "'B', with `this.bar = true`": {
+            topic: function () {
+                this.bar = true;
+                var self = this;
+                process.nextTick(function(){
+                  self.callback(null, 42);
+                })
+            },
+            "should pass the result": function (res) {
+                assert.equal(res, 42);
+            },
+            "should have `this.bar` set to true": function (res) {
+                assert.equal(this.bar, true);
+            },
+            'with a sub context': {
+              topic: function(){
+                this.barSubContext = { sub: true };
+                var self = this;
+                process.nextTick(function(){
+                  self.callback(null, 42);
+                })
+              },
+              "should have `this.foo` set to true": function (res) {
+                  assert.equal(this.bar, true);
+              },
+              "should have `this.fooSubContext`": function (res) {
+                  assert.deepEqual(this.barSubContext, { sub: true });
+              },
+              'with gaps': {
+                '.': {
+                  '.': {
+                    '.': {
+                      topic: 12,
+                      '.': {
+                        '.': {
+                          topic: function(){
+                            this.barSubContext.subsub = true;
+                            var self = this;
+                            process.nextTick(function(){
+                              self.callback(null, 42);
+                            })
+                          },
+                          "should have `this.bar` set to true": function (res) {
+                              assert.equal(this.bar, true);
+                          },
+                          'should have `this.barSubContext': function(){
+                            assert.deepEqual(this.barSubContext, { sub: true, subsub: true });
+                          }
+                        }
+                      }
+                    }
+                  }
+                }
+              }
+            }
+        },
+        "'C', with nothing set": {
+            topic: function () {
+                var self = this;
+                process.nextTick(function(){
+                  self.callback(null, self);
+                })
+            },
             "shouldn't have access to `this.foo`": function (e, res) {
                 assert.isUndefined(res.foo);
+            },
+            "shouldn't have access to `this.bar`": function (e, res) {
+                assert.isUndefined(res.bar);
+            },
+            "shouldn't have access to `this.barSubContext`": function (e, res) {
+                assert.isUndefined(res.barSubContext);
             }
+
         }
     }
 }).addBatch({
@@ -445,12 +581,12 @@ vows.describe("Vows with sub events").addBatch({
                 events.EventEmitter.call(this);
             };
             require('util').inherits(MyEmitter, events.EventEmitter);
-    
+
             var topic = new(MyEmitter);
             process.nextTick(function () {
                 topic.emit('success', 'Legacy Does not Catch');
             });
-    
+
             return topic;
         },
         "will return the emitter for traditional vows" : function (err, ret) {
